@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2003 Marco Pesenti Gritti
- *  Copyright (C) 2003 Christian Persch
+ *  Copyright © 2003 Marco Pesenti Gritti
+ *  Copyright © 2003 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-adblock-extension.c,v 1.10 2006/03/11 18:41:20 jframeau Exp $
+ *  $Id: ephy-adblock-extension.c,v 1.17 2006/12/17 18:48:31 jframeau Exp $
  */
 
 #include "config.h"
@@ -31,15 +31,20 @@
 
 #include "ephy-adblock-extension.h"
 #include "ephy-debug.h"
+#include "ephy-file-helpers.h"
 
 #include "ad-blocker.h"
 #include "ad-uri-tester.h"
+#include "adblock-ui.h"
 
+#include <gtk/gtkaction.h>
+#include <gtk/gtkactiongroup.h>
 #include <gtk/gtkeventbox.h>
-#include <gtk/gtkframe.h>
 #include <gtk/gtkiconfactory.h>
 #include <gtk/gtkimage.h>
 #include <gtk/gtknotebook.h>
+#include <gtk/gtkuimanager.h>
+#include <gtk/gtkstock.h>
 
 #include <gmodule.h>
 
@@ -47,14 +52,28 @@
 
 #define EPHY_ADBLOCK_EXTENSION_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_ADBLOCK_EXTENSION, EphyAdblockExtensionPrivate))
 
+#define WINDOW_DATA_KEY		"EphyAdblockExtensionWindowData"
 #define STATUSBAR_FRAME_KEY	"EphyAdblockExtensionStatusbarFrame"
 #define STATUSBAR_EVBOX_KEY	"EphyAdblockExtensionStatusbarEvbox"
 #define EXTENSION_KEY		"EphyAdblockExtension"
 #define ICON_FILENAME		"adblock-statusbar-icon.svg"
 
+typedef struct
+{
+	EphyAdblockExtension	*extension;
+	EphyWindow		*window;
+
+	GtkActionGroup		*action_group;
+	guint			ui_id;
+} WindowData;
+
+static void ephy_adblock_extension_edit_cb (GtkAction *action,
+					    EphyWindow *window);
+
 struct EphyAdblockExtensionPrivate
 {
 	AdUriTester *tester;
+	AdblockUI   *ui;
 };
 
 static void ephy_adblock_extension_class_init	(EphyAdblockExtensionClass *klass);
@@ -76,7 +95,7 @@ ephy_adblock_extension_get_type (void)
 GType
 ephy_adblock_extension_register_type (GTypeModule *module)
 {
-	static const GTypeInfo our_info =
+	const GTypeInfo our_info =
 	{
 		sizeof (EphyAdblockExtensionClass),
 		NULL, /* base_init */
@@ -89,14 +108,14 @@ ephy_adblock_extension_register_type (GTypeModule *module)
 		(GInstanceInitFunc) ephy_adblock_extension_init
 	};
 
-	static const GInterfaceInfo adblock_info =
+	const GInterfaceInfo adblock_info =
 	{
 		(GInterfaceInitFunc) ephy_adblock_adblock_iface_init,
 		NULL,
 		NULL
 	};
 
-	static const GInterfaceInfo extension_info =
+	const GInterfaceInfo extension_info =
 	{
 		(GInterfaceInitFunc) ephy_adblock_extension_iface_init,
 		NULL,
@@ -125,6 +144,7 @@ static void
 ephy_adblock_extension_init (EphyAdblockExtension *extension)
 {
 	EphyAdBlockManager *manager;
+	char *dirname;
 
 	LOG ("EphyAdblockExtension initialising");
 
@@ -132,9 +152,14 @@ ephy_adblock_extension_init (EphyAdblockExtension *extension)
 
 	extension->priv->tester = ad_uri_tester_new ();
 
-	/* register our extention as a blocker */
-	manager = EPHY_ADBLOCK_MANAGER (ephy_embed_shell_get_adblock_manager (embed_shell));
+	/* ensure adblock's dir is there */
+	dirname =  g_build_filename (ephy_dot_dir (), "extensions", "adblock", "data", NULL);
+	g_mkdir_with_parents (dirname, 0775);
+	g_free (dirname);
 
+	/* register our extention as a blocker */
+	manager = EPHY_ADBLOCK_MANAGER (
+			ephy_embed_shell_get_adblock_manager (embed_shell));
 	ephy_adblock_manager_set_blocker (manager, EPHY_ADBLOCK (extension));
 }
 
@@ -149,14 +174,20 @@ ephy_adblock_extension_finalize (GObject *object)
 	/* unregister our extension as a blocker */
 	manager = EPHY_ADBLOCK_MANAGER (ephy_embed_shell_get_adblock_manager (embed_shell));
 	ephy_adblock_manager_set_blocker (manager, NULL);
-
+	
+	if (extension->priv->ui != NULL)
+	{
+		g_object_unref (extension->priv->ui);
+	}
 	g_object_unref (extension->priv->tester);
 
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
 static gboolean
-ephy_adblock_impl_should_load (EphyAdBlock *blocker, const char *url, AdUriCheckType type)
+ephy_adblock_impl_should_load (EphyAdBlock *blocker, 
+			       const char *url, 
+			       AdUriCheckType type)
 {
 	EphyAdblockExtension *self;
 
@@ -168,6 +199,68 @@ ephy_adblock_impl_should_load (EphyAdBlock *blocker, const char *url, AdUriCheck
 	return !ad_uri_tester_test_uri (self->priv->tester, url, type);
 }
 
+static void
+ephy_adblock_impl_edit_rule (EphyAdBlock *blocker, 
+			     const char *url, 
+			     gboolean allowed)
+{
+	EphyAdblockExtension *self;
+	EphyAdblockExtensionPrivate *priv;
+
+	LOG ("ephy_adblock_impl_edit_rule %s with state %d", url, allowed);
+
+	self = EPHY_ADBLOCK_EXTENSION (blocker);
+	priv = self->priv;
+
+	if (priv->ui == NULL)
+	{
+		AdblockUI **ui;
+ 
+		priv->ui =  g_object_new (TYPE_ADBLOCK_UI, 
+					  "tester"     , priv->tester, 
+					  "url"        , url, 
+					  "url_allowed", allowed,
+					  NULL);
+		ui = &priv->ui;
+
+		g_object_add_weak_pointer ((gpointer)priv->ui,
+				           (gpointer *) ui);
+	
+		ephy_dialog_set_parent (EPHY_DIALOG (priv->ui), NULL);
+	}
+
+	ephy_dialog_show (EPHY_DIALOG (priv->ui));
+}
+
+
+static const GtkActionEntry edit_entries[] = {
+	{ "EphyAdblockExtensionEdit", NULL, N_("Adblock editor"), NULL,
+	  N_("Edit Adblock"),
+	  G_CALLBACK (ephy_adblock_extension_edit_cb) }
+};
+
+static gboolean
+ephy_adblock_statusbar_icon_clicked_cb (GtkWidget *widget,
+				        GdkEventButton *event,
+				        EphyWindow *window)
+{
+	if (event->button == 1)
+	{
+		GtkAction *action;
+
+		action = gtk_ui_manager_get_action (
+				GTK_UI_MANAGER (ephy_window_get_ui_manager (window)),
+					        "/menubar/ViewMenu/PageInfo");
+		g_return_val_if_fail (action != NULL, TRUE);
+
+		gtk_action_activate (action);
+
+		return TRUE;
+	}
+
+	return FALSE;
+}
+
 static void
 update_statusbar (EphyWindow *window)
 {
@@ -175,7 +268,6 @@ update_statusbar (EphyWindow *window)
 	EphyEmbed *embed;
 	GObject *statusbar;
 	GtkWidget *evbox;
-	GtkWidget *frame;
 	int num_blocked;
 
 	embed = ephy_window_get_active_embed (window);
@@ -187,9 +279,6 @@ update_statusbar (EphyWindow *window)
 	statusbar = G_OBJECT (ephy_window_get_statusbar (window));
 	g_return_if_fail (statusbar != NULL);
 
-	frame = g_object_get_data (statusbar, STATUSBAR_FRAME_KEY);
-	g_return_if_fail (frame != NULL);
-
 	evbox = g_object_get_data (statusbar, STATUSBAR_EVBOX_KEY);
 	g_return_if_fail (evbox != NULL);
 
@@ -197,7 +286,7 @@ update_statusbar (EphyWindow *window)
 
 	if (num_blocked == 0)
 	{
-		gtk_widget_hide (frame);
+		gtk_widget_hide (evbox);
 	}
 	else
 	{
@@ -208,12 +297,12 @@ update_statusbar (EphyWindow *window)
 						     num_blocked),
 					   num_blocked);
 
-		gtk_tooltips_set_tip ((EPHY_STATUSBAR(statusbar))->tooltips,
+		gtk_tooltips_set_tip ((EPHY_STATUSBAR (statusbar))->tooltips,
 				      evbox, tooltip, NULL);
 
 		g_free (tooltip);
 
-		gtk_widget_show (frame);
+		gtk_widget_show (evbox);
 	}
 }
 
@@ -223,65 +312,92 @@ create_statusbar_icon (EphyWindow *window)
 	EphyStatusbar *statusbar;
 	char *filename;
 	GdkPixbuf *pixbuf;
-	GtkWidget *frame;
 	GtkWidget *icon;
 	GtkWidget *evbox;
 	int w, h;
 
 	gtk_icon_size_lookup (GTK_ICON_SIZE_MENU, &w, &h);
 
+	/* FIXME themeing! */
 	filename = g_build_filename (SHARE_DIR, ICON_FILENAME, NULL);
 	pixbuf = gdk_pixbuf_new_from_file_at_size (filename, w, h, NULL);
 	g_free (filename);
-	g_return_if_fail (pixbuf != NULL);
+
+	/* Try not to crash when librsvg isn't installed! */
+	if (pixbuf)
+	{
+		icon = gtk_image_new_from_pixbuf (pixbuf);
+		g_object_unref (pixbuf);
+	}
+	else
+	{
+		icon = gtk_image_new_from_stock (GTK_STOCK_MISSING_IMAGE, GTK_ICON_SIZE_MENU);
+	}
 
 	statusbar = EPHY_STATUSBAR (ephy_window_get_statusbar (window));
 	g_return_if_fail (statusbar != NULL);
 
-	frame = gtk_frame_new (NULL);
-
-	icon = gtk_image_new_from_pixbuf (pixbuf);
-
 	evbox = gtk_event_box_new ();
 	gtk_event_box_set_visible_window (GTK_EVENT_BOX (evbox), FALSE);
 
-	gtk_container_add (GTK_CONTAINER (frame), evbox);
 	gtk_container_add (GTK_CONTAINER (evbox), icon);
 
-	gtk_widget_show (evbox);
 	gtk_widget_show (icon);
-	/* don't show the frame */
+	/* don't show the evbox */
 
-	ephy_statusbar_add_widget (statusbar, frame);
+	ephy_statusbar_add_widget (statusbar, evbox);
 
-	g_object_set_data (G_OBJECT (statusbar), STATUSBAR_FRAME_KEY, frame);
 	g_object_set_data (G_OBJECT (statusbar), STATUSBAR_EVBOX_KEY, evbox);
 
-	g_object_unref (pixbuf);
+	g_signal_connect_after (evbox, "button-press-event",
+				G_CALLBACK (ephy_adblock_statusbar_icon_clicked_cb),
+				window);
 }
 
 static void
 destroy_statusbar_icon (EphyWindow *window)
 {
 	EphyStatusbar *statusbar;
-	GtkWidget *frame;
 	GtkWidget *evbox;
 
 	statusbar = EPHY_STATUSBAR (ephy_window_get_statusbar (window));
 	g_return_if_fail (statusbar != NULL);
 
-	frame = g_object_get_data (G_OBJECT (statusbar), STATUSBAR_FRAME_KEY);
-	evbox = g_object_get_data (G_OBJECT (statusbar), STATUSBAR_EVBOX_KEY);
+	evbox = g_object_steal_data (G_OBJECT (statusbar), STATUSBAR_EVBOX_KEY);
 
-	g_object_set_data (G_OBJECT (statusbar), STATUSBAR_FRAME_KEY, NULL);
-	g_object_set_data (G_OBJECT (statusbar), STATUSBAR_EVBOX_KEY, NULL);
-
-	g_return_if_fail (frame != NULL);
 	g_return_if_fail (evbox != NULL);
 
 	gtk_tooltips_set_tip (statusbar->tooltips, evbox, NULL, NULL);
 
-	ephy_statusbar_remove_widget (statusbar, frame);
+	ephy_statusbar_remove_widget (statusbar, evbox);
+}
+
+static void
+ephy_adblock_extension_edit_cb (GtkAction *action, EphyWindow *window)
+{
+	WindowData *data;
+	EphyAdblockExtensionPrivate *priv;
+	
+	data = g_object_get_data (G_OBJECT (window), WINDOW_DATA_KEY);
+	g_return_if_fail (data != NULL);
+
+	priv = data->extension->priv;
+
+	if (priv->ui == NULL)
+	{
+		AdblockUI **ui;
+
+		priv->ui =  g_object_new (TYPE_ADBLOCK_UI, 
+					  "tester", priv->tester, 
+					  NULL);
+		ui = &priv->ui;
+
+		g_object_add_weak_pointer ((gpointer)priv->ui,
+				           (gpointer *) ui);
+	}
+
+	ephy_dialog_set_parent (EPHY_DIALOG (priv->ui), GTK_WIDGET (window));
+	ephy_dialog_show (EPHY_DIALOG (priv->ui));
 }
 
 static void
@@ -290,6 +406,7 @@ switch_page_cb (GtkNotebook *notebook,
 		guint page_num,
 		EphyWindow *window)
 {
+	/* FIXME: this shouldn't happen anymore with gtk 2.10 ! Test & remove */
 	if (GTK_WIDGET_REALIZED (window) == FALSE) return; /* on startup */
 
 	update_statusbar (window);
@@ -300,10 +417,45 @@ impl_attach_window (EphyExtension *ext,
 		    EphyWindow *window)
 {
 	GtkWidget *notebook;
+	WindowData *data;
+	GtkUIManager *manager;
 
+	/* Add adblock editor's menu entry */
+	data = g_new (WindowData, 1);
+	g_object_set_data_full (G_OBJECT (window), 
+			 	WINDOW_DATA_KEY, 
+				data,
+				g_free);
+
+	data->extension = EPHY_ADBLOCK_EXTENSION (ext);
+	data->window = window;
+
+	data->action_group = gtk_action_group_new ("EphyAdblockExtension");
+	gtk_action_group_set_translation_domain (data->action_group,
+						 GETTEXT_PACKAGE);
+	gtk_action_group_add_actions (data->action_group, edit_entries,
+				      G_N_ELEMENTS(edit_entries), window);
+
+	manager = GTK_UI_MANAGER (ephy_window_get_ui_manager (window));
+
+	gtk_ui_manager_insert_action_group (manager, data->action_group, -1);
+	/* ui manager refs the new action group */
+	g_object_unref (data->action_group);
+
+	data->ui_id = gtk_ui_manager_new_merge_id (manager);
+
+	gtk_ui_manager_add_ui (manager,
+			       data->ui_id,
+			       "/menubar/ToolsMenu",
+			       "EphyAdblockExtensionEdit",
+			       "EphyAdblockExtensionEdit",
+			       GTK_UI_MANAGER_MENUITEM,
+			       FALSE);
+	
 	/* Remember the xtension attached to that window */
 	g_object_set_data (G_OBJECT (window), EXTENSION_KEY, ext);
 
+	/* The ad blocked icon */
 	create_statusbar_icon (window);
 
 	notebook = ephy_window_get_notebook (window);
@@ -317,7 +469,21 @@ impl_detach_window (EphyExtension *ext,
 		    EphyWindow *window)
 {
 	GtkWidget *notebook;
+	WindowData *data;
+	GtkUIManager *manager;
 
+	/* Remove editor ui */
+	data = g_object_get_data (G_OBJECT (window), WINDOW_DATA_KEY);
+	g_assert (data != NULL);
+
+	manager = GTK_UI_MANAGER (ephy_window_get_ui_manager (window));
+
+	gtk_ui_manager_remove_ui (manager, data->ui_id);
+	gtk_ui_manager_remove_action_group (manager, data->action_group);
+
+	g_object_set_data (G_OBJECT (window), WINDOW_DATA_KEY, NULL);
+
+	/* Remove icon stuff */
 	notebook = ephy_window_get_notebook (window);
 
 	g_signal_handlers_disconnect_by_func
@@ -365,7 +531,8 @@ num_blocked_cb (AdBlocker *blocker,
 }
 
 static AdBlocker *
-ensure_adblocker (EphyWindow *window, EphyEmbed *embed)
+ensure_adblocker (EphyWindow *window,
+		  EphyEmbed *embed)
 {
 	AdBlocker *blocker;
 
@@ -379,22 +546,22 @@ ensure_adblocker (EphyWindow *window, EphyEmbed *embed)
 								 EXTENSION_KEY));
 		g_return_val_if_fail (ext != NULL, NULL);
 
-		blocker = ad_blocker_new (ext->priv->tester);
+		blocker = ad_blocker_new ();
 		g_return_val_if_fail (blocker != NULL, NULL);
 
-		g_object_set_data (G_OBJECT (embed), AD_BLOCKER_KEY, blocker);
+		g_object_set_data_full (G_OBJECT (embed), AD_BLOCKER_KEY,
+					blocker, (GDestroyNotify) g_object_unref);
 
 		g_signal_connect (embed, "ge-location",
-				G_CALLBACK (location_changed_cb), blocker);
+				  G_CALLBACK (location_changed_cb), blocker);
 
 		g_signal_connect (embed, "content-blocked",
-				G_CALLBACK (content_blocked_cb), blocker);
+				  G_CALLBACK (content_blocked_cb), blocker);
 	}
 
 	return blocker;
 }
 
-
 static void
 impl_attach_tab (EphyExtension *ext,
 		 EphyWindow *window,
@@ -422,15 +589,15 @@ impl_detach_tab (EphyExtension *ext,
 	
 	embed = ephy_tab_get_embed (tab);
 
-	blocker = g_object_get_data (G_OBJECT (embed), AD_BLOCKER_KEY);
+	blocker = g_object_steal_data (G_OBJECT (embed), AD_BLOCKER_KEY);
 	g_return_if_fail (blocker != NULL);
 
 	g_signal_handlers_disconnect_by_func
-		(G_OBJECT (embed), G_CALLBACK (content_blocked_cb), blocker);
+		(embed, G_CALLBACK (content_blocked_cb), blocker);
 	g_signal_handlers_disconnect_by_func
-		(G_OBJECT (embed), G_CALLBACK (location_changed_cb), blocker);
+		(embed, G_CALLBACK (location_changed_cb), blocker);
 	g_signal_handlers_disconnect_by_func
-		(G_OBJECT (blocker), G_CALLBACK (num_blocked_cb), blocker);
+		(blocker, G_CALLBACK (num_blocked_cb), embed);
 
 	g_object_unref (blocker);
 }
@@ -439,6 +606,7 @@ static void
 ephy_adblock_adblock_iface_init (EphyAdBlockIface *iface)
 {
 	iface->should_load = ephy_adblock_impl_should_load;
+	iface->edit_rule   = ephy_adblock_impl_edit_rule;
 }
 
 static void
