@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2003 Marco Pesenti Gritti
- *  Copyright (C) 2003 Christian Persch
+ *  Copyright © 2003 Marco Pesenti Gritti
+ *  Copyright © 2003 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,13 +16,14 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: extension.c,v 1.7 2005/01/28 22:28:56 chpe Exp $
+ *  $Id: extension.c,v 1.9 2006/12/17 18:48:31 jframeau Exp $
  */
 
 #include "config.h"
 
 #include "ephy-adblock-extension.h"
 #include "ad-blocker.h"
+#include "adblock-ui.h"
 #include "ephy-debug.h"
 
 #include <gmodule.h>
@@ -43,5 +44,6 @@ register_module (GTypeModule *module)
 
 	ad_blocker_register_type (module);
 	ad_uri_tester_register_type (module);
+	adblock_ui_register_type (module);
 	return ephy_adblock_extension_register_type (module);
 }
