@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2003 Marco Pesenti Gritti
- *  Copyright (C) 2003 Christian Persch
+ *  Copyright © 2003 Marco Pesenti Gritti
+ *  Copyright © 2003 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-gestures-extension.c,v 1.23 2005/08/28 12:30:03 chpe Exp $
+ *  $Id: ephy-gestures-extension.c,v 1.26 2006/09/13 19:01:16 chpe Exp $
  */
 
 #include "config.h"
@@ -29,13 +29,8 @@
 
 #include <epiphany/ephy-embed.h>
 #include <epiphany/ephy-tab.h>
-#include <epiphany/ephy-window.h>
 #include <epiphany/ephy-extension.h>
 
-#include <gtk/gtkaction.h>
-#include <gtk/gtkactiongroup.h>
-#include <gtk/gtkuimanager.h>
-
 #include <gmodule.h>
 #include <libxml/tree.h>
 
@@ -73,7 +68,7 @@ ephy_gestures_extension_get_type (void)
 GType
 ephy_gestures_extension_register_type (GTypeModule *module)
 {
-	static const GTypeInfo our_info =
+	const GTypeInfo our_info =
 	{
 		sizeof (EphyGesturesExtensionClass),
 		NULL, /* base_init */
@@ -86,7 +81,7 @@ ephy_gestures_extension_register_type (GTypeModule *module)
 		(GInstanceInitFunc) ephy_gestures_extension_init
 	};
 
-	static const GInterfaceInfo extension_info =
+	const GInterfaceInfo extension_info =
 	{
 		(GInterfaceInitFunc) ephy_gestures_extension_iface_init,
 		NULL,
@@ -242,52 +237,14 @@ gesture_performed_cb (EphyGesture *gesture,
 		      const char *sequence,
 		      EphyGesturesExtension *extension)
 {
-	EphyWindow *window;
 	const char *path;
 
 	LOG ("Gesture: sequence '%s'", sequence);
 
 	path = g_hash_table_lookup (extension->priv->gestures, sequence);
-	if (path == NULL)
+	if (path)
 	{
-		return;
-	}
-
-	window = EPHY_WINDOW (ephy_gesture_get_window (gesture));
-	g_return_if_fail (EPHY_IS_WINDOW (window));
-
-	if (strcmp (path, "fallback") == 0)
-	{
-		/* Fall back to normal click */
-		EphyEmbed *embed;
-		EphyEmbedEvent *event;
-		gint handled = FALSE;
-
-		embed = ephy_window_get_active_embed (window);
-		g_return_if_fail (EPHY_IS_EMBED (embed));
-
-		event = ephy_gesture_get_event (gesture);
-		g_return_if_fail (EPHY_IS_EMBED_EVENT (event));
-
-		g_signal_emit_by_name (embed, "ge_dom_mouse_click", event,
-				       &handled);
-	}
-	else
-	{
-		GtkUIManager *manager;
-		GtkAction *action;
-		
-		manager = GTK_UI_MANAGER (ephy_window_get_ui_manager (window));
-		
-		action = gtk_ui_manager_get_action (manager, path);
-		
-		if (action == NULL)
-		{
-			g_warning ("Action for path '%s' not found!\n", path);
-			return;
-		}
-
-		gtk_action_activate (action);
+		ephy_gesture_activate(gesture, path);
 	}
 }
 
