@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004 Crispin Flowerday
+ *  Copyright © 2004 Crispin Flowerday
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: ephy-sidebar-embed.c,v 1.15 2006/01/18 15:42:03 jframeau Exp $
+ * $Id: ephy-sidebar-embed.c,v 1.17 2006/09/13 19:01:36 chpe Exp $
  */
 
 #include "config.h"
@@ -83,7 +83,7 @@ ephy_sidebar_embed_get_type (void)
 GType
 ephy_sidebar_embed_register_type (GTypeModule *module)
 {
-	static const GTypeInfo our_info =
+	const GTypeInfo our_info =
 	{
 		sizeof (EphySidebarEmbedClass),
 		NULL, /* base_init */
