@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2000 Marco Pesenti Gritti
- *  Copyright (C) 2004 Jean-François Rameau
+ *  Copyright © 2000 Marco Pesenti Gritti
+ *  Copyright © 2004 Jean-François Rameau
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,34 +16,32 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-selection.cpp,v 1.6 2005/09/09 16:39:12 jframeau Exp $
+ *  $Id: mozilla-selection.cpp,v 1.8 2006/09/13 19:01:37 chpe Exp $
  */
 
 #include "mozilla-config.h"
-
 #include "config.h"
 
-#include "mozilla-selection.h"
-
 #include <glib.h>
 
-#undef MOZILLA_INTERNAL_API
-#include <nsEmbedString.h>
-#define MOZILLA_INTERNAL_API 1
-#include <nsCOMPtr.h>
-#include <nsISelection.h>
+#include <nsStringAPI.h>
+
 #include <gtkmozembed.h>
-#include <nsIWebBrowser.h>
-#include <nsIDOMWindow.h>
+#include <gtkmozembed_internal.h>
+#include <nsCOMPtr.h>
 #include <nsIDOMElement.h>
 #include <nsIDOMHTMLInputElement.h>
+#include <nsIDOMHTMLTextAreaElement.h>
 #include <nsIDOMNSHTMLInputElement.h>
 #include <nsIDOMNSHTMLTextAreaElement.h>
-#include <nsIDOMHTMLTextAreaElement.h>
+#include <nsIDOMWindow.h>
+#include <nsISelection.h>
 #include <nsIWebBrowserFocus.h>
-#include <gtkmozembed_internal.h>
+#include <nsIWebBrowser.h>
 #include <nsMemory.h>
 
+#include "mozilla-selection.h"
+
 template <class NST, class T>
 char * get_selection (nsIDOMElement *aElement)
 {
@@ -57,7 +55,7 @@ char * get_selection (nsIDOMElement *aElement)
 	nsElement->GetSelectionEnd (&end);
 
 	// Get full text in element
-	nsEmbedString text; 
+	nsString text; 
 	nsCOMPtr<T> element (do_QueryInterface(aElement));
 	element->GetValue(text);
 
@@ -65,7 +63,7 @@ char * get_selection (nsIDOMElement *aElement)
 	text.Cut (end, text.Length());
 	text.Cut (0, start);
 
-	nsEmbedCString cText; 
+	nsCString cText; 
 	NS_UTF16ToCString(text, NS_CSTRING_ENCODING_UTF8, cText);
 
 	if (cText.Length () == 0) return NULL;
@@ -94,11 +92,11 @@ mozilla_get_selected_text (EphyEmbed *embed)
 
 	PRUnichar *selText = nsnull; 
 	nsSelection->ToString(&selText);
-	nsEmbedString text(selText);
+	nsString text(selText);
 
 	if (text.Length () > 0)
 	{
-		nsEmbedCString cText; 
+		nsCString cText; 
 		NS_UTF16ToCString(text, NS_CSTRING_ENCODING_UTF8, cText);
 
 		nsMemory::Free (selText);
